(module object2
   (import (object1 "object1.scm"))
   (export (class foo2::foo1
	      y)
	   (class bar3::bar2
	      c)
	   (final-class wx x)
	   (wide-class ws::wx y)))

   
